@@ -11,41 +11,41 @@ from json_streams.utility import types
 # pylint: disable=unsubscriptable-object
 
 
-def dump(data: Union[Dict, Iterable], fp: BinaryIO):
+def dump(data: Union[Dict, Iterable], fp: BinaryIO, **kwargs):
 
     if isinstance(data, dict):
-        fp.write(jsonlib.dumps(data))
+        fp.write(jsonlib.dumps(data, **kwargs))
         fp.write(b"\n")
         return
 
     try:
         for obj in data:
-            fp.write(jsonlib.dumps(obj))
+            fp.write(jsonlib.dumps(obj, **kwargs))
             fp.write(b"\n")
     except TypeError:
-        fp.write(jsonlib.dumps(data))
+        fp.write(jsonlib.dumps(data, **kwargs))
         fp.write(b"\n")
 
 
-def load(fp: BinaryIO) -> Iterable:
+def load(fp: BinaryIO, **kwargs) -> Iterable:
     for line in fp:
-        yield jsonlib.loads(line)
+        yield jsonlib.loads(line, **kwargs)
 
 
-def load_from_file(file_name: types.Pathlike, *, file_mode: str = None):
+def load_from_file(file_name: types.Pathlike, *, file_mode: str = None, **kwargs):
     if not file_mode:
         file_mode = "br"
     assert "b" in file_mode
     with open(file_name, file_mode) as fp:
-        yield from load(fp)  # type: ignore
+        yield from load(fp, **kwargs)  # type: ignore
 
 
-def dump_to_file(obj, file_name: types.Pathlike, *, file_mode: str = None):
+def dump_to_file(obj, file_name: types.Pathlike, *, file_mode: str = None, **kwargs):
     if not file_mode:
         file_mode = "bw"
     assert "b" in file_mode
     with open(file_name, file_mode) as fp:
-        dump(obj, fp)  # type: ignore
+        dump(obj, fp, **kwargs)  # type: ignore
 
 
 def sink(fp: BinaryIO):
